## 📖 Destilação de pull request
  - Conceito: usaremos a funcao do github Review PR para um humano corrigir ou aprovar as melhorias feitas no pull request 
  - Anotacoes: isso significa que criamos um pull request com melhorias usando autopullrequest e logo em seguida verificamos a aprovacao comentarios ou se o pull request foi recusado ou aprovado e mergeado 



# passos 

- [X] Criamos um pull request com melhorias usando autopullrequest
- [] Verificamos usando checkcommentspr verificamos o status que pode ser `pull request aberto, pull request recusado, pull request aprovado e mergeado ` 
- [] Verificamos o comment mais recente que é um Comentario Humano apontando o erro no pull request 
- [] Usamos o Comentario Humano para Destilação especial onde a mensagem é ultra longa contendo o inicio do desenvolvimento da melhoria ate o aprovamento e merge do pull request 
- [] O Agente so é finalizado quando o status do pull request é `pull request aprovado e mergeado `



